<?php
/**
 * Template for single posts.
 *
 * WordPress identifies this file by its name (which MUST be single.php)
 * and displays it whenever a single post is displayed.
 * 
 * Posts are generally used to present a piece of information that is relevant 
 * during a certain timespan, like a news article. After that time, the contents
 * often lose most of its relevance, aren't updated anymore (even if it means information
 * presented in a post stops to be accurate due to its old age) and kept only for
 * archival purposes.
 * Posts display an author and a post date.
 * 
 * Pages, on the other hand, contain information that is always relevant and should
 * always be kept up to date, see page.php for more.
 *
 * @see https://codex.wordpress.org/Theme_Development#Single_Post_.28single.php.29
 */

get_header();
?>
<main>
    <?php the_post(); ?>
    <article>
        <header style="background-image:url('<?php if(has_post_thumbnail()) {
                // A header configured specifically for this post
                the_post_thumbnail_url();
            } else {
                // Fall back to the default header (which can be configured site-wide, so we can't hardcode the URL)
                header_image();
            } ?>')">
            <h1><?php the_title(); ?></h1>
        </header>
        <div class="content">
            <?php the_content(); ?>
        </div>
        <footer>
            <div class="post-meta-author"><?php the_author_meta('display_name'); ?></div>
            <time><?php the_date(); ?></time>
        </footer>
    </article>
</main>
<?php get_footer(); ?>
